TakeOwned

Trait TakeOwned 

pub trait TakeOwned {
    type Item;

    // Required method
    fn take_owned(self, n: usize) -> Vec<Self::Item>;
}
Returns an owned slice of the start of a vector. Provides owned start of the provided vector.

Required Associated Types

Required Methods

fn take_owned(self, n: usize) -> Vec<Self::Item>

Returns up to n items from the start of the vector.

Implementations on Foreign Types

Source

impl<T> TakeOwned for Vec<T>

Source

type Item = T

Source

fn take_owned(self, n: usize) -> Vec<Self::Item>

Implementors