pub trait TakeOwned {
type Item;
// Required method
fn take_owned(self, n: usize) -> Vec<Self::Item>;
}Expand description
Returns an owned slice of the start of a vector. Provides owned start of the provided vector.
Required Associated Types
Required Methods
Sourcefn take_owned(self, n: usize) -> Vec<Self::Item>
fn take_owned(self, n: usize) -> Vec<Self::Item>
Returns up to n items from the start of the vector.